.. pylcp documentation master file, created by
   sphinx-quickstart on Thu Sep  3 20:44:00 2020.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to pylcp!
=================

`pylcp` is a python package meant to help with the calculation of a variety of
interesting quantities in laser cooling physics.  At its heart, it allows for
automatic generation of the optical Bloch equations or some approximation
thereof given a atom or molecule internal Hamiltonian, a set of laser beams, and
a possible magnetic field.

.. toctree::
  :maxdepth: 2

  installation
  getting_started
  examples
  detailed_reference

Support
-------

Join our google group: https://groups.google.com/g/pylcp/

Credits
-------

:Authors:
    Stephen Eckel,
    Daniel Barker,
    Eric Norrgard
:Contributors:
    Abrar Sheikh,
    Shangjie Guo,
    Chad Ropp,
    Leo Wang


:Cite as:
    Stephen Eckel, Daniel Barker, Eric Norrgard, and Julia Scherschligt,
    "PyLCP: A python package for computing laser cooling physics",
    in preparation (2020).

:Version: 1.0.0 of 2020/11/10

:Disclaimer:
  The full description of the procedures used in this documentation requires
  the identification of certain commercial products. The inclusion of such
  information should in no way be construed as indicating that such products
  are endorsed by NIST or are recommended by NIST or that they are necessarily
  the best software for the purposes described.

Indices and tables
------------------

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
